# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'FlexibleServerCustomerManagedKey',
    'FlexibleServerHighAvailability',
    'FlexibleServerIdentity',
    'FlexibleServerMaintenanceWindow',
    'FlexibleServerStorage',
    'ServerIdentity',
    'ServerThreatDetectionPolicy',
    'GetFlexibleServerHighAvailabilityResult',
    'GetFlexibleServerMaintenanceWindowResult',
    'GetFlexibleServerStorageResult',
    'GetServerIdentityResult',
    'GetServerThreatDetectionPolicyResult',
]

@pulumi.output_type
class FlexibleServerCustomerManagedKey(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "geoBackupKeyVaultKeyId":
            suggest = "geo_backup_key_vault_key_id"
        elif key == "geoBackupUserAssignedIdentityId":
            suggest = "geo_backup_user_assigned_identity_id"
        elif key == "keyVaultKeyId":
            suggest = "key_vault_key_id"
        elif key == "primaryUserAssignedIdentityId":
            suggest = "primary_user_assigned_identity_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FlexibleServerCustomerManagedKey. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FlexibleServerCustomerManagedKey.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FlexibleServerCustomerManagedKey.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 geo_backup_key_vault_key_id: Optional[str] = None,
                 geo_backup_user_assigned_identity_id: Optional[str] = None,
                 key_vault_key_id: Optional[str] = None,
                 primary_user_assigned_identity_id: Optional[str] = None):
        """
        :param str geo_backup_key_vault_key_id: The ID of the geo backup Key Vault Key. It can't cross region and need Customer Managed Key in same region as geo backup.
        :param str geo_backup_user_assigned_identity_id: The geo backup user managed identity id for a Customer Managed Key. Should be added with `identity_ids`. It can't cross region and need identity in same region as geo backup.
               
               > **NOTE:** `primary_user_assigned_identity_id` or `geo_backup_user_assigned_identity_id` is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        :param str key_vault_key_id: The ID of the Key Vault Key.
        :param str primary_user_assigned_identity_id: Specifies the primary user managed identity id for a Customer Managed Key. Should be added with `identity_ids`.
        """
        FlexibleServerCustomerManagedKey._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            geo_backup_key_vault_key_id=geo_backup_key_vault_key_id,
            geo_backup_user_assigned_identity_id=geo_backup_user_assigned_identity_id,
            key_vault_key_id=key_vault_key_id,
            primary_user_assigned_identity_id=primary_user_assigned_identity_id,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             geo_backup_key_vault_key_id: Optional[str] = None,
             geo_backup_user_assigned_identity_id: Optional[str] = None,
             key_vault_key_id: Optional[str] = None,
             primary_user_assigned_identity_id: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if geo_backup_key_vault_key_id is None and 'geoBackupKeyVaultKeyId' in kwargs:
            geo_backup_key_vault_key_id = kwargs['geoBackupKeyVaultKeyId']
        if geo_backup_user_assigned_identity_id is None and 'geoBackupUserAssignedIdentityId' in kwargs:
            geo_backup_user_assigned_identity_id = kwargs['geoBackupUserAssignedIdentityId']
        if key_vault_key_id is None and 'keyVaultKeyId' in kwargs:
            key_vault_key_id = kwargs['keyVaultKeyId']
        if primary_user_assigned_identity_id is None and 'primaryUserAssignedIdentityId' in kwargs:
            primary_user_assigned_identity_id = kwargs['primaryUserAssignedIdentityId']

        if geo_backup_key_vault_key_id is not None:
            _setter("geo_backup_key_vault_key_id", geo_backup_key_vault_key_id)
        if geo_backup_user_assigned_identity_id is not None:
            _setter("geo_backup_user_assigned_identity_id", geo_backup_user_assigned_identity_id)
        if key_vault_key_id is not None:
            _setter("key_vault_key_id", key_vault_key_id)
        if primary_user_assigned_identity_id is not None:
            _setter("primary_user_assigned_identity_id", primary_user_assigned_identity_id)

    @property
    @pulumi.getter(name="geoBackupKeyVaultKeyId")
    def geo_backup_key_vault_key_id(self) -> Optional[str]:
        """
        The ID of the geo backup Key Vault Key. It can't cross region and need Customer Managed Key in same region as geo backup.
        """
        return pulumi.get(self, "geo_backup_key_vault_key_id")

    @property
    @pulumi.getter(name="geoBackupUserAssignedIdentityId")
    def geo_backup_user_assigned_identity_id(self) -> Optional[str]:
        """
        The geo backup user managed identity id for a Customer Managed Key. Should be added with `identity_ids`. It can't cross region and need identity in same region as geo backup.

        > **NOTE:** `primary_user_assigned_identity_id` or `geo_backup_user_assigned_identity_id` is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        return pulumi.get(self, "geo_backup_user_assigned_identity_id")

    @property
    @pulumi.getter(name="keyVaultKeyId")
    def key_vault_key_id(self) -> Optional[str]:
        """
        The ID of the Key Vault Key.
        """
        return pulumi.get(self, "key_vault_key_id")

    @property
    @pulumi.getter(name="primaryUserAssignedIdentityId")
    def primary_user_assigned_identity_id(self) -> Optional[str]:
        """
        Specifies the primary user managed identity id for a Customer Managed Key. Should be added with `identity_ids`.
        """
        return pulumi.get(self, "primary_user_assigned_identity_id")


@pulumi.output_type
class FlexibleServerHighAvailability(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "standbyAvailabilityZone":
            suggest = "standby_availability_zone"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FlexibleServerHighAvailability. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FlexibleServerHighAvailability.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FlexibleServerHighAvailability.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 mode: str,
                 standby_availability_zone: Optional[str] = None):
        """
        :param str mode: The high availability mode for the MySQL Flexible Server. Possibles values are `SameZone` and `ZoneRedundant`.
               
               > **NOTE:** `storage.0.auto_grow_enabled` must be enabled when `high_availability` is enabled. To change the `high_availability` for a MySQL Flexible Server created with `high_availability` disabled during creation, the resource has to be recreated.
        """
        FlexibleServerHighAvailability._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            mode=mode,
            standby_availability_zone=standby_availability_zone,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             mode: Optional[str] = None,
             standby_availability_zone: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if mode is None:
            raise TypeError("Missing 'mode' argument")
        if standby_availability_zone is None and 'standbyAvailabilityZone' in kwargs:
            standby_availability_zone = kwargs['standbyAvailabilityZone']

        _setter("mode", mode)
        if standby_availability_zone is not None:
            _setter("standby_availability_zone", standby_availability_zone)

    @property
    @pulumi.getter
    def mode(self) -> str:
        """
        The high availability mode for the MySQL Flexible Server. Possibles values are `SameZone` and `ZoneRedundant`.

        > **NOTE:** `storage.0.auto_grow_enabled` must be enabled when `high_availability` is enabled. To change the `high_availability` for a MySQL Flexible Server created with `high_availability` disabled during creation, the resource has to be recreated.
        """
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter(name="standbyAvailabilityZone")
    def standby_availability_zone(self) -> Optional[str]:
        return pulumi.get(self, "standby_availability_zone")


@pulumi.output_type
class FlexibleServerIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityIds":
            suggest = "identity_ids"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FlexibleServerIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FlexibleServerIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FlexibleServerIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 identity_ids: Sequence[str],
                 type: str):
        """
        :param Sequence[str] identity_ids: A list of User Assigned Managed Identity IDs to be assigned to this MySQL Flexible Server.
        :param str type: Specifies the type of Managed Service Identity that should be configured on this MySQL Flexible Server. The only possible value is `UserAssigned`.
        """
        FlexibleServerIdentity._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            identity_ids=identity_ids,
            type=type,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             identity_ids: Optional[Sequence[str]] = None,
             type: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if identity_ids is None and 'identityIds' in kwargs:
            identity_ids = kwargs['identityIds']
        if identity_ids is None:
            raise TypeError("Missing 'identity_ids' argument")
        if type is None:
            raise TypeError("Missing 'type' argument")

        _setter("identity_ids", identity_ids)
        _setter("type", type)

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Sequence[str]:
        """
        A list of User Assigned Managed Identity IDs to be assigned to this MySQL Flexible Server.
        """
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Specifies the type of Managed Service Identity that should be configured on this MySQL Flexible Server. The only possible value is `UserAssigned`.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class FlexibleServerMaintenanceWindow(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dayOfWeek":
            suggest = "day_of_week"
        elif key == "startHour":
            suggest = "start_hour"
        elif key == "startMinute":
            suggest = "start_minute"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FlexibleServerMaintenanceWindow. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FlexibleServerMaintenanceWindow.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FlexibleServerMaintenanceWindow.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 day_of_week: Optional[int] = None,
                 start_hour: Optional[int] = None,
                 start_minute: Optional[int] = None):
        """
        :param int day_of_week: The day of week for maintenance window. Defaults to `0`.
        :param int start_hour: The start hour for maintenance window. Defaults to `0`.
        :param int start_minute: The start minute for maintenance window. Defaults to `0`.
        """
        FlexibleServerMaintenanceWindow._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            day_of_week=day_of_week,
            start_hour=start_hour,
            start_minute=start_minute,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             day_of_week: Optional[int] = None,
             start_hour: Optional[int] = None,
             start_minute: Optional[int] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if day_of_week is None and 'dayOfWeek' in kwargs:
            day_of_week = kwargs['dayOfWeek']
        if start_hour is None and 'startHour' in kwargs:
            start_hour = kwargs['startHour']
        if start_minute is None and 'startMinute' in kwargs:
            start_minute = kwargs['startMinute']

        if day_of_week is not None:
            _setter("day_of_week", day_of_week)
        if start_hour is not None:
            _setter("start_hour", start_hour)
        if start_minute is not None:
            _setter("start_minute", start_minute)

    @property
    @pulumi.getter(name="dayOfWeek")
    def day_of_week(self) -> Optional[int]:
        """
        The day of week for maintenance window. Defaults to `0`.
        """
        return pulumi.get(self, "day_of_week")

    @property
    @pulumi.getter(name="startHour")
    def start_hour(self) -> Optional[int]:
        """
        The start hour for maintenance window. Defaults to `0`.
        """
        return pulumi.get(self, "start_hour")

    @property
    @pulumi.getter(name="startMinute")
    def start_minute(self) -> Optional[int]:
        """
        The start minute for maintenance window. Defaults to `0`.
        """
        return pulumi.get(self, "start_minute")


@pulumi.output_type
class FlexibleServerStorage(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "autoGrowEnabled":
            suggest = "auto_grow_enabled"
        elif key == "ioScalingEnabled":
            suggest = "io_scaling_enabled"
        elif key == "sizeGb":
            suggest = "size_gb"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FlexibleServerStorage. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FlexibleServerStorage.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FlexibleServerStorage.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 auto_grow_enabled: Optional[bool] = None,
                 io_scaling_enabled: Optional[bool] = None,
                 iops: Optional[int] = None,
                 size_gb: Optional[int] = None):
        """
        :param bool auto_grow_enabled: Should Storage Auto Grow be enabled? Defaults to `true`.
        :param bool io_scaling_enabled: Should IOPS be scaled automatically? If `true`, `iops` can not be set. Defaults to `false`.
        :param int iops: The storage IOPS for the MySQL Flexible Server. Possible values are between `360` and `20000`.
        :param int size_gb: The max storage allowed for the MySQL Flexible Server. Possible values are between `20` and `16384`.
        """
        FlexibleServerStorage._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            auto_grow_enabled=auto_grow_enabled,
            io_scaling_enabled=io_scaling_enabled,
            iops=iops,
            size_gb=size_gb,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             auto_grow_enabled: Optional[bool] = None,
             io_scaling_enabled: Optional[bool] = None,
             iops: Optional[int] = None,
             size_gb: Optional[int] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if auto_grow_enabled is None and 'autoGrowEnabled' in kwargs:
            auto_grow_enabled = kwargs['autoGrowEnabled']
        if io_scaling_enabled is None and 'ioScalingEnabled' in kwargs:
            io_scaling_enabled = kwargs['ioScalingEnabled']
        if size_gb is None and 'sizeGb' in kwargs:
            size_gb = kwargs['sizeGb']

        if auto_grow_enabled is not None:
            _setter("auto_grow_enabled", auto_grow_enabled)
        if io_scaling_enabled is not None:
            _setter("io_scaling_enabled", io_scaling_enabled)
        if iops is not None:
            _setter("iops", iops)
        if size_gb is not None:
            _setter("size_gb", size_gb)

    @property
    @pulumi.getter(name="autoGrowEnabled")
    def auto_grow_enabled(self) -> Optional[bool]:
        """
        Should Storage Auto Grow be enabled? Defaults to `true`.
        """
        return pulumi.get(self, "auto_grow_enabled")

    @property
    @pulumi.getter(name="ioScalingEnabled")
    def io_scaling_enabled(self) -> Optional[bool]:
        """
        Should IOPS be scaled automatically? If `true`, `iops` can not be set. Defaults to `false`.
        """
        return pulumi.get(self, "io_scaling_enabled")

    @property
    @pulumi.getter
    def iops(self) -> Optional[int]:
        """
        The storage IOPS for the MySQL Flexible Server. Possible values are between `360` and `20000`.
        """
        return pulumi.get(self, "iops")

    @property
    @pulumi.getter(name="sizeGb")
    def size_gb(self) -> Optional[int]:
        """
        The max storage allowed for the MySQL Flexible Server. Possible values are between `20` and `16384`.
        """
        return pulumi.get(self, "size_gb")


@pulumi.output_type
class ServerIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "principalId":
            suggest = "principal_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ServerIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ServerIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ServerIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 principal_id: Optional[str] = None,
                 tenant_id: Optional[str] = None):
        """
        :param str type: Specifies the type of Managed Service Identity that should be configured on this MySQL Server. The only possible value is `SystemAssigned`.
        :param str principal_id: The Principal ID associated with this Managed Service Identity.
        :param str tenant_id: The Tenant ID associated with this Managed Service Identity.
        """
        ServerIdentity._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            type=type,
            principal_id=principal_id,
            tenant_id=tenant_id,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             type: Optional[str] = None,
             principal_id: Optional[str] = None,
             tenant_id: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if type is None:
            raise TypeError("Missing 'type' argument")
        if principal_id is None and 'principalId' in kwargs:
            principal_id = kwargs['principalId']
        if tenant_id is None and 'tenantId' in kwargs:
            tenant_id = kwargs['tenantId']

        _setter("type", type)
        if principal_id is not None:
            _setter("principal_id", principal_id)
        if tenant_id is not None:
            _setter("tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Specifies the type of Managed Service Identity that should be configured on this MySQL Server. The only possible value is `SystemAssigned`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[str]:
        """
        The Principal ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[str]:
        """
        The Tenant ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class ServerThreatDetectionPolicy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "disabledAlerts":
            suggest = "disabled_alerts"
        elif key == "emailAccountAdmins":
            suggest = "email_account_admins"
        elif key == "emailAddresses":
            suggest = "email_addresses"
        elif key == "retentionDays":
            suggest = "retention_days"
        elif key == "storageAccountAccessKey":
            suggest = "storage_account_access_key"
        elif key == "storageEndpoint":
            suggest = "storage_endpoint"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ServerThreatDetectionPolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ServerThreatDetectionPolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ServerThreatDetectionPolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 disabled_alerts: Optional[Sequence[str]] = None,
                 email_account_admins: Optional[bool] = None,
                 email_addresses: Optional[Sequence[str]] = None,
                 enabled: Optional[bool] = None,
                 retention_days: Optional[int] = None,
                 storage_account_access_key: Optional[str] = None,
                 storage_endpoint: Optional[str] = None):
        """
        :param Sequence[str] disabled_alerts: Specifies a list of alerts which should be disabled. Possible values are `Sql_Injection`, `Sql_Injection_Vulnerability`, `Access_Anomaly`, `Data_Exfiltration` and `Unsafe_Action`.
        :param bool email_account_admins: Should the account administrators be emailed when this alert is triggered?
        :param Sequence[str] email_addresses: A list of email addresses which alerts should be sent to.
        :param bool enabled: Is the policy enabled?
        :param int retention_days: Specifies the number of days to keep in the Threat Detection audit logs.
        :param str storage_account_access_key: Specifies the identifier key of the Threat Detection audit storage account.
        :param str storage_endpoint: Specifies the blob storage endpoint (e.g. <https://example.blob.core.windows.net>). This blob storage will hold all Threat Detection audit logs.
        """
        ServerThreatDetectionPolicy._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            disabled_alerts=disabled_alerts,
            email_account_admins=email_account_admins,
            email_addresses=email_addresses,
            enabled=enabled,
            retention_days=retention_days,
            storage_account_access_key=storage_account_access_key,
            storage_endpoint=storage_endpoint,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             disabled_alerts: Optional[Sequence[str]] = None,
             email_account_admins: Optional[bool] = None,
             email_addresses: Optional[Sequence[str]] = None,
             enabled: Optional[bool] = None,
             retention_days: Optional[int] = None,
             storage_account_access_key: Optional[str] = None,
             storage_endpoint: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if disabled_alerts is None and 'disabledAlerts' in kwargs:
            disabled_alerts = kwargs['disabledAlerts']
        if email_account_admins is None and 'emailAccountAdmins' in kwargs:
            email_account_admins = kwargs['emailAccountAdmins']
        if email_addresses is None and 'emailAddresses' in kwargs:
            email_addresses = kwargs['emailAddresses']
        if retention_days is None and 'retentionDays' in kwargs:
            retention_days = kwargs['retentionDays']
        if storage_account_access_key is None and 'storageAccountAccessKey' in kwargs:
            storage_account_access_key = kwargs['storageAccountAccessKey']
        if storage_endpoint is None and 'storageEndpoint' in kwargs:
            storage_endpoint = kwargs['storageEndpoint']

        if disabled_alerts is not None:
            _setter("disabled_alerts", disabled_alerts)
        if email_account_admins is not None:
            _setter("email_account_admins", email_account_admins)
        if email_addresses is not None:
            _setter("email_addresses", email_addresses)
        if enabled is not None:
            _setter("enabled", enabled)
        if retention_days is not None:
            _setter("retention_days", retention_days)
        if storage_account_access_key is not None:
            _setter("storage_account_access_key", storage_account_access_key)
        if storage_endpoint is not None:
            _setter("storage_endpoint", storage_endpoint)

    @property
    @pulumi.getter(name="disabledAlerts")
    def disabled_alerts(self) -> Optional[Sequence[str]]:
        """
        Specifies a list of alerts which should be disabled. Possible values are `Sql_Injection`, `Sql_Injection_Vulnerability`, `Access_Anomaly`, `Data_Exfiltration` and `Unsafe_Action`.
        """
        return pulumi.get(self, "disabled_alerts")

    @property
    @pulumi.getter(name="emailAccountAdmins")
    def email_account_admins(self) -> Optional[bool]:
        """
        Should the account administrators be emailed when this alert is triggered?
        """
        return pulumi.get(self, "email_account_admins")

    @property
    @pulumi.getter(name="emailAddresses")
    def email_addresses(self) -> Optional[Sequence[str]]:
        """
        A list of email addresses which alerts should be sent to.
        """
        return pulumi.get(self, "email_addresses")

    @property
    @pulumi.getter
    def enabled(self) -> Optional[bool]:
        """
        Is the policy enabled?
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="retentionDays")
    def retention_days(self) -> Optional[int]:
        """
        Specifies the number of days to keep in the Threat Detection audit logs.
        """
        return pulumi.get(self, "retention_days")

    @property
    @pulumi.getter(name="storageAccountAccessKey")
    def storage_account_access_key(self) -> Optional[str]:
        """
        Specifies the identifier key of the Threat Detection audit storage account.
        """
        return pulumi.get(self, "storage_account_access_key")

    @property
    @pulumi.getter(name="storageEndpoint")
    def storage_endpoint(self) -> Optional[str]:
        """
        Specifies the blob storage endpoint (e.g. <https://example.blob.core.windows.net>). This blob storage will hold all Threat Detection audit logs.
        """
        return pulumi.get(self, "storage_endpoint")


@pulumi.output_type
class GetFlexibleServerHighAvailabilityResult(dict):
    def __init__(__self__, *,
                 mode: str,
                 standby_availability_zone: str):
        """
        :param str mode: The high availability mode of the MySQL Flexible Server.
        :param str standby_availability_zone: The availability zone of the standby Flexible Server.
        """
        GetFlexibleServerHighAvailabilityResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            mode=mode,
            standby_availability_zone=standby_availability_zone,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             mode: Optional[str] = None,
             standby_availability_zone: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if mode is None:
            raise TypeError("Missing 'mode' argument")
        if standby_availability_zone is None and 'standbyAvailabilityZone' in kwargs:
            standby_availability_zone = kwargs['standbyAvailabilityZone']
        if standby_availability_zone is None:
            raise TypeError("Missing 'standby_availability_zone' argument")

        _setter("mode", mode)
        _setter("standby_availability_zone", standby_availability_zone)

    @property
    @pulumi.getter
    def mode(self) -> str:
        """
        The high availability mode of the MySQL Flexible Server.
        """
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter(name="standbyAvailabilityZone")
    def standby_availability_zone(self) -> str:
        """
        The availability zone of the standby Flexible Server.
        """
        return pulumi.get(self, "standby_availability_zone")


@pulumi.output_type
class GetFlexibleServerMaintenanceWindowResult(dict):
    def __init__(__self__, *,
                 day_of_week: int,
                 start_hour: int,
                 start_minute: int):
        """
        :param int day_of_week: The day of week of the maintenance window.
        :param int start_hour: The start hour of the maintenance window.
        :param int start_minute: The start minute of the maintenance window.
        """
        GetFlexibleServerMaintenanceWindowResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            day_of_week=day_of_week,
            start_hour=start_hour,
            start_minute=start_minute,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             day_of_week: Optional[int] = None,
             start_hour: Optional[int] = None,
             start_minute: Optional[int] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if day_of_week is None and 'dayOfWeek' in kwargs:
            day_of_week = kwargs['dayOfWeek']
        if day_of_week is None:
            raise TypeError("Missing 'day_of_week' argument")
        if start_hour is None and 'startHour' in kwargs:
            start_hour = kwargs['startHour']
        if start_hour is None:
            raise TypeError("Missing 'start_hour' argument")
        if start_minute is None and 'startMinute' in kwargs:
            start_minute = kwargs['startMinute']
        if start_minute is None:
            raise TypeError("Missing 'start_minute' argument")

        _setter("day_of_week", day_of_week)
        _setter("start_hour", start_hour)
        _setter("start_minute", start_minute)

    @property
    @pulumi.getter(name="dayOfWeek")
    def day_of_week(self) -> int:
        """
        The day of week of the maintenance window.
        """
        return pulumi.get(self, "day_of_week")

    @property
    @pulumi.getter(name="startHour")
    def start_hour(self) -> int:
        """
        The start hour of the maintenance window.
        """
        return pulumi.get(self, "start_hour")

    @property
    @pulumi.getter(name="startMinute")
    def start_minute(self) -> int:
        """
        The start minute of the maintenance window.
        """
        return pulumi.get(self, "start_minute")


@pulumi.output_type
class GetFlexibleServerStorageResult(dict):
    def __init__(__self__, *,
                 auto_grow_enabled: bool,
                 io_scaling_enabled: bool,
                 iops: int,
                 size_gb: int):
        """
        :param bool auto_grow_enabled: Is Storage Auto Grow enabled?
        :param bool io_scaling_enabled: Should IOPS be scaled automatically?
        :param int iops: The storage IOPS of the MySQL Flexible Server.
        :param int size_gb: The max storage allowed for the MySQL Flexible Server.
        """
        GetFlexibleServerStorageResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            auto_grow_enabled=auto_grow_enabled,
            io_scaling_enabled=io_scaling_enabled,
            iops=iops,
            size_gb=size_gb,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             auto_grow_enabled: Optional[bool] = None,
             io_scaling_enabled: Optional[bool] = None,
             iops: Optional[int] = None,
             size_gb: Optional[int] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if auto_grow_enabled is None and 'autoGrowEnabled' in kwargs:
            auto_grow_enabled = kwargs['autoGrowEnabled']
        if auto_grow_enabled is None:
            raise TypeError("Missing 'auto_grow_enabled' argument")
        if io_scaling_enabled is None and 'ioScalingEnabled' in kwargs:
            io_scaling_enabled = kwargs['ioScalingEnabled']
        if io_scaling_enabled is None:
            raise TypeError("Missing 'io_scaling_enabled' argument")
        if iops is None:
            raise TypeError("Missing 'iops' argument")
        if size_gb is None and 'sizeGb' in kwargs:
            size_gb = kwargs['sizeGb']
        if size_gb is None:
            raise TypeError("Missing 'size_gb' argument")

        _setter("auto_grow_enabled", auto_grow_enabled)
        _setter("io_scaling_enabled", io_scaling_enabled)
        _setter("iops", iops)
        _setter("size_gb", size_gb)

    @property
    @pulumi.getter(name="autoGrowEnabled")
    def auto_grow_enabled(self) -> bool:
        """
        Is Storage Auto Grow enabled?
        """
        return pulumi.get(self, "auto_grow_enabled")

    @property
    @pulumi.getter(name="ioScalingEnabled")
    def io_scaling_enabled(self) -> bool:
        """
        Should IOPS be scaled automatically?
        """
        return pulumi.get(self, "io_scaling_enabled")

    @property
    @pulumi.getter
    def iops(self) -> int:
        """
        The storage IOPS of the MySQL Flexible Server.
        """
        return pulumi.get(self, "iops")

    @property
    @pulumi.getter(name="sizeGb")
    def size_gb(self) -> int:
        """
        The max storage allowed for the MySQL Flexible Server.
        """
        return pulumi.get(self, "size_gb")


@pulumi.output_type
class GetServerIdentityResult(dict):
    def __init__(__self__, *,
                 principal_id: str,
                 tenant_id: str,
                 type: str):
        """
        :param str principal_id: The Principal ID associated with this Managed Service Identity.
        :param str tenant_id: The Tenant ID associated with this Managed Service Identity.
        :param str type: The identity type of this Managed Service Identity.
        """
        GetServerIdentityResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            principal_id=principal_id,
            tenant_id=tenant_id,
            type=type,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             principal_id: Optional[str] = None,
             tenant_id: Optional[str] = None,
             type: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if principal_id is None and 'principalId' in kwargs:
            principal_id = kwargs['principalId']
        if principal_id is None:
            raise TypeError("Missing 'principal_id' argument")
        if tenant_id is None and 'tenantId' in kwargs:
            tenant_id = kwargs['tenantId']
        if tenant_id is None:
            raise TypeError("Missing 'tenant_id' argument")
        if type is None:
            raise TypeError("Missing 'type' argument")

        _setter("principal_id", principal_id)
        _setter("tenant_id", tenant_id)
        _setter("type", type)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> str:
        """
        The Principal ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        """
        The Tenant ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The identity type of this Managed Service Identity.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetServerThreatDetectionPolicyResult(dict):
    def __init__(__self__, *,
                 disabled_alerts: Sequence[str],
                 email_account_admins: bool,
                 email_addresses: Sequence[str],
                 enabled: bool,
                 retention_days: int,
                 storage_account_access_key: str,
                 storage_endpoint: str):
        """
        :param Sequence[str] disabled_alerts: Specifies a list of alerts which should be disabled. Possible values include `Access_Anomaly`, `Sql_Injection` and `Sql_Injection_Vulnerability`.
        :param bool email_account_admins: Should the account administrators be emailed when this alert is triggered?
        :param Sequence[str] email_addresses: A list of email addresses which alerts should be sent to.
        :param bool enabled: Is the policy enabled?
        :param int retention_days: Specifies the number of days to keep in the Threat Detection audit logs.
        :param str storage_account_access_key: Specifies the identifier key of the Threat Detection audit storage account.
        :param str storage_endpoint: Specifies the blob storage endpoint (e.g. <https://example.blob.core.windows.net>). This blob storage will hold all Threat Detection audit logs.
        """
        GetServerThreatDetectionPolicyResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            disabled_alerts=disabled_alerts,
            email_account_admins=email_account_admins,
            email_addresses=email_addresses,
            enabled=enabled,
            retention_days=retention_days,
            storage_account_access_key=storage_account_access_key,
            storage_endpoint=storage_endpoint,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             disabled_alerts: Optional[Sequence[str]] = None,
             email_account_admins: Optional[bool] = None,
             email_addresses: Optional[Sequence[str]] = None,
             enabled: Optional[bool] = None,
             retention_days: Optional[int] = None,
             storage_account_access_key: Optional[str] = None,
             storage_endpoint: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if disabled_alerts is None and 'disabledAlerts' in kwargs:
            disabled_alerts = kwargs['disabledAlerts']
        if disabled_alerts is None:
            raise TypeError("Missing 'disabled_alerts' argument")
        if email_account_admins is None and 'emailAccountAdmins' in kwargs:
            email_account_admins = kwargs['emailAccountAdmins']
        if email_account_admins is None:
            raise TypeError("Missing 'email_account_admins' argument")
        if email_addresses is None and 'emailAddresses' in kwargs:
            email_addresses = kwargs['emailAddresses']
        if email_addresses is None:
            raise TypeError("Missing 'email_addresses' argument")
        if enabled is None:
            raise TypeError("Missing 'enabled' argument")
        if retention_days is None and 'retentionDays' in kwargs:
            retention_days = kwargs['retentionDays']
        if retention_days is None:
            raise TypeError("Missing 'retention_days' argument")
        if storage_account_access_key is None and 'storageAccountAccessKey' in kwargs:
            storage_account_access_key = kwargs['storageAccountAccessKey']
        if storage_account_access_key is None:
            raise TypeError("Missing 'storage_account_access_key' argument")
        if storage_endpoint is None and 'storageEndpoint' in kwargs:
            storage_endpoint = kwargs['storageEndpoint']
        if storage_endpoint is None:
            raise TypeError("Missing 'storage_endpoint' argument")

        _setter("disabled_alerts", disabled_alerts)
        _setter("email_account_admins", email_account_admins)
        _setter("email_addresses", email_addresses)
        _setter("enabled", enabled)
        _setter("retention_days", retention_days)
        _setter("storage_account_access_key", storage_account_access_key)
        _setter("storage_endpoint", storage_endpoint)

    @property
    @pulumi.getter(name="disabledAlerts")
    def disabled_alerts(self) -> Sequence[str]:
        """
        Specifies a list of alerts which should be disabled. Possible values include `Access_Anomaly`, `Sql_Injection` and `Sql_Injection_Vulnerability`.
        """
        return pulumi.get(self, "disabled_alerts")

    @property
    @pulumi.getter(name="emailAccountAdmins")
    def email_account_admins(self) -> bool:
        """
        Should the account administrators be emailed when this alert is triggered?
        """
        return pulumi.get(self, "email_account_admins")

    @property
    @pulumi.getter(name="emailAddresses")
    def email_addresses(self) -> Sequence[str]:
        """
        A list of email addresses which alerts should be sent to.
        """
        return pulumi.get(self, "email_addresses")

    @property
    @pulumi.getter
    def enabled(self) -> bool:
        """
        Is the policy enabled?
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="retentionDays")
    def retention_days(self) -> int:
        """
        Specifies the number of days to keep in the Threat Detection audit logs.
        """
        return pulumi.get(self, "retention_days")

    @property
    @pulumi.getter(name="storageAccountAccessKey")
    def storage_account_access_key(self) -> str:
        """
        Specifies the identifier key of the Threat Detection audit storage account.
        """
        return pulumi.get(self, "storage_account_access_key")

    @property
    @pulumi.getter(name="storageEndpoint")
    def storage_endpoint(self) -> str:
        """
        Specifies the blob storage endpoint (e.g. <https://example.blob.core.windows.net>). This blob storage will hold all Threat Detection audit logs.
        """
        return pulumi.get(self, "storage_endpoint")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ServiceCorArgs',
    'ServiceIdentityArgs',
    'ServiceLiveTraceArgs',
    'ServiceNetworkAclPrivateEndpointArgs',
    'ServiceNetworkAclPublicNetworkArgs',
    'ServiceSkuArgs',
    'ServiceUpstreamEndpointArgs',
]

@pulumi.input_type
class ServiceCorArgs:
    def __init__(__self__, *,
                 allowed_origins: pulumi.Input[Sequence[pulumi.Input[str]]]):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_origins: A list of origins which should be able to make cross-origin calls. `*` can be used to allow all calls.
        """
        ServiceCorArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            allowed_origins=allowed_origins,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             allowed_origins: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if allowed_origins is None and 'allowedOrigins' in kwargs:
            allowed_origins = kwargs['allowedOrigins']
        if allowed_origins is None:
            raise TypeError("Missing 'allowed_origins' argument")

        _setter("allowed_origins", allowed_origins)

    @property
    @pulumi.getter(name="allowedOrigins")
    def allowed_origins(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        A list of origins which should be able to make cross-origin calls. `*` can be used to allow all calls.
        """
        return pulumi.get(self, "allowed_origins")

    @allowed_origins.setter
    def allowed_origins(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "allowed_origins", value)


@pulumi.input_type
class ServiceIdentityArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[str],
                 identity_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 principal_id: Optional[pulumi.Input[str]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] type: Specifies the type of Managed Service Identity that should be configured on this signalR. Possible values are `SystemAssigned`, `UserAssigned`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] identity_ids: Specifies a list of User Assigned Managed Identity IDs to be assigned to this signalR.
               
               > **NOTE:** This is required when `type` is set to `UserAssigned`
        """
        ServiceIdentityArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            type=type,
            identity_ids=identity_ids,
            principal_id=principal_id,
            tenant_id=tenant_id,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             type: Optional[pulumi.Input[str]] = None,
             identity_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             principal_id: Optional[pulumi.Input[str]] = None,
             tenant_id: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if type is None:
            raise TypeError("Missing 'type' argument")
        if identity_ids is None and 'identityIds' in kwargs:
            identity_ids = kwargs['identityIds']
        if principal_id is None and 'principalId' in kwargs:
            principal_id = kwargs['principalId']
        if tenant_id is None and 'tenantId' in kwargs:
            tenant_id = kwargs['tenantId']

        _setter("type", type)
        if identity_ids is not None:
            _setter("identity_ids", identity_ids)
        if principal_id is not None:
            _setter("principal_id", principal_id)
        if tenant_id is not None:
            _setter("tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Specifies the type of Managed Service Identity that should be configured on this signalR. Possible values are `SystemAssigned`, `UserAssigned`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies a list of User Assigned Managed Identity IDs to be assigned to this signalR.

        > **NOTE:** This is required when `type` is set to `UserAssigned`
        """
        return pulumi.get(self, "identity_ids")

    @identity_ids.setter
    def identity_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "identity_ids", value)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "principal_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.input_type
class ServiceLiveTraceArgs:
    def __init__(__self__, *,
                 connectivity_logs_enabled: Optional[pulumi.Input[bool]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 http_request_logs_enabled: Optional[pulumi.Input[bool]] = None,
                 messaging_logs_enabled: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[bool] connectivity_logs_enabled: Whether the log category `ConnectivityLogs` is enabled? Defaults to `true`
        :param pulumi.Input[bool] enabled: Whether the live trace is enabled? Defaults to `true`.
        :param pulumi.Input[bool] http_request_logs_enabled: Whether the log category `HttpRequestLogs` is enabled? Defaults to `true`
        :param pulumi.Input[bool] messaging_logs_enabled: Whether the log category `MessagingLogs` is enabled? Defaults to `true`
        """
        ServiceLiveTraceArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            connectivity_logs_enabled=connectivity_logs_enabled,
            enabled=enabled,
            http_request_logs_enabled=http_request_logs_enabled,
            messaging_logs_enabled=messaging_logs_enabled,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             connectivity_logs_enabled: Optional[pulumi.Input[bool]] = None,
             enabled: Optional[pulumi.Input[bool]] = None,
             http_request_logs_enabled: Optional[pulumi.Input[bool]] = None,
             messaging_logs_enabled: Optional[pulumi.Input[bool]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if connectivity_logs_enabled is None and 'connectivityLogsEnabled' in kwargs:
            connectivity_logs_enabled = kwargs['connectivityLogsEnabled']
        if http_request_logs_enabled is None and 'httpRequestLogsEnabled' in kwargs:
            http_request_logs_enabled = kwargs['httpRequestLogsEnabled']
        if messaging_logs_enabled is None and 'messagingLogsEnabled' in kwargs:
            messaging_logs_enabled = kwargs['messagingLogsEnabled']

        if connectivity_logs_enabled is not None:
            _setter("connectivity_logs_enabled", connectivity_logs_enabled)
        if enabled is not None:
            _setter("enabled", enabled)
        if http_request_logs_enabled is not None:
            _setter("http_request_logs_enabled", http_request_logs_enabled)
        if messaging_logs_enabled is not None:
            _setter("messaging_logs_enabled", messaging_logs_enabled)

    @property
    @pulumi.getter(name="connectivityLogsEnabled")
    def connectivity_logs_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the log category `ConnectivityLogs` is enabled? Defaults to `true`
        """
        return pulumi.get(self, "connectivity_logs_enabled")

    @connectivity_logs_enabled.setter
    def connectivity_logs_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "connectivity_logs_enabled", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the live trace is enabled? Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="httpRequestLogsEnabled")
    def http_request_logs_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the log category `HttpRequestLogs` is enabled? Defaults to `true`
        """
        return pulumi.get(self, "http_request_logs_enabled")

    @http_request_logs_enabled.setter
    def http_request_logs_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "http_request_logs_enabled", value)

    @property
    @pulumi.getter(name="messagingLogsEnabled")
    def messaging_logs_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the log category `MessagingLogs` is enabled? Defaults to `true`
        """
        return pulumi.get(self, "messaging_logs_enabled")

    @messaging_logs_enabled.setter
    def messaging_logs_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "messaging_logs_enabled", value)


@pulumi.input_type
class ServiceNetworkAclPrivateEndpointArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[str],
                 allowed_request_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 denied_request_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[str] id: The ID of the Private Endpoint which is based on the SignalR service.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_request_types: The allowed request types for the Private Endpoint Connection. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.
               
               > **Note:** When `default_action` is `Allow`, `allowed_request_types`cannot be set.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] denied_request_types: The denied request types for the Private Endpoint Connection. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.
               
               > **Note:** When `default_action` is `Deny`, `denied_request_types`cannot be set.
               
               > **Note:** `allowed_request_types` - (Optional) and `denied_request_types` cannot be set together.
        """
        ServiceNetworkAclPrivateEndpointArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            id=id,
            allowed_request_types=allowed_request_types,
            denied_request_types=denied_request_types,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             id: Optional[pulumi.Input[str]] = None,
             allowed_request_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             denied_request_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if id is None:
            raise TypeError("Missing 'id' argument")
        if allowed_request_types is None and 'allowedRequestTypes' in kwargs:
            allowed_request_types = kwargs['allowedRequestTypes']
        if denied_request_types is None and 'deniedRequestTypes' in kwargs:
            denied_request_types = kwargs['deniedRequestTypes']

        _setter("id", id)
        if allowed_request_types is not None:
            _setter("allowed_request_types", allowed_request_types)
        if denied_request_types is not None:
            _setter("denied_request_types", denied_request_types)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        """
        The ID of the Private Endpoint which is based on the SignalR service.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="allowedRequestTypes")
    def allowed_request_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The allowed request types for the Private Endpoint Connection. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.

        > **Note:** When `default_action` is `Allow`, `allowed_request_types`cannot be set.
        """
        return pulumi.get(self, "allowed_request_types")

    @allowed_request_types.setter
    def allowed_request_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "allowed_request_types", value)

    @property
    @pulumi.getter(name="deniedRequestTypes")
    def denied_request_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The denied request types for the Private Endpoint Connection. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.

        > **Note:** When `default_action` is `Deny`, `denied_request_types`cannot be set.

        > **Note:** `allowed_request_types` - (Optional) and `denied_request_types` cannot be set together.
        """
        return pulumi.get(self, "denied_request_types")

    @denied_request_types.setter
    def denied_request_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "denied_request_types", value)


@pulumi.input_type
class ServiceNetworkAclPublicNetworkArgs:
    def __init__(__self__, *,
                 allowed_request_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 denied_request_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_request_types: The allowed request types for the public network. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.
               
               > **Note:** When `default_action` is `Allow`, `allowed_request_types`cannot be set.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] denied_request_types: The denied request types for the public network. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.
               
               > **Note:** When `default_action` is `Deny`, `denied_request_types`cannot be set.
               
               > **Note:** `allowed_request_types` - (Optional) and `denied_request_types` cannot be set together.
        """
        ServiceNetworkAclPublicNetworkArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            allowed_request_types=allowed_request_types,
            denied_request_types=denied_request_types,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             allowed_request_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             denied_request_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if allowed_request_types is None and 'allowedRequestTypes' in kwargs:
            allowed_request_types = kwargs['allowedRequestTypes']
        if denied_request_types is None and 'deniedRequestTypes' in kwargs:
            denied_request_types = kwargs['deniedRequestTypes']

        if allowed_request_types is not None:
            _setter("allowed_request_types", allowed_request_types)
        if denied_request_types is not None:
            _setter("denied_request_types", denied_request_types)

    @property
    @pulumi.getter(name="allowedRequestTypes")
    def allowed_request_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The allowed request types for the public network. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.

        > **Note:** When `default_action` is `Allow`, `allowed_request_types`cannot be set.
        """
        return pulumi.get(self, "allowed_request_types")

    @allowed_request_types.setter
    def allowed_request_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "allowed_request_types", value)

    @property
    @pulumi.getter(name="deniedRequestTypes")
    def denied_request_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The denied request types for the public network. Possible values are `ClientConnection`, `ServerConnection`, `RESTAPI` and `Trace`.

        > **Note:** When `default_action` is `Deny`, `denied_request_types`cannot be set.

        > **Note:** `allowed_request_types` - (Optional) and `denied_request_types` cannot be set together.
        """
        return pulumi.get(self, "denied_request_types")

    @denied_request_types.setter
    def denied_request_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "denied_request_types", value)


@pulumi.input_type
class ServiceSkuArgs:
    def __init__(__self__, *,
                 capacity: pulumi.Input[int],
                 name: pulumi.Input[str]):
        """
        :param pulumi.Input[int] capacity: Specifies the number of units associated with this SignalR service. Valid values are `1`, `2`, `3`, `4`, `5`, `6`, `7`, `8`, `9`, `10`, `20`, `30`, `40`, `50`, `60`, `70`, `80`, `90` and `100`.
        :param pulumi.Input[str] name: Specifies which tier to use. Valid values are `Free_F1`, `Standard_S1` and `Premium_P1`.
        """
        ServiceSkuArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            capacity=capacity,
            name=name,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             capacity: Optional[pulumi.Input[int]] = None,
             name: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if capacity is None:
            raise TypeError("Missing 'capacity' argument")
        if name is None:
            raise TypeError("Missing 'name' argument")

        _setter("capacity", capacity)
        _setter("name", name)

    @property
    @pulumi.getter
    def capacity(self) -> pulumi.Input[int]:
        """
        Specifies the number of units associated with this SignalR service. Valid values are `1`, `2`, `3`, `4`, `5`, `6`, `7`, `8`, `9`, `10`, `20`, `30`, `40`, `50`, `60`, `70`, `80`, `90` and `100`.
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: pulumi.Input[int]):
        pulumi.set(self, "capacity", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Specifies which tier to use. Valid values are `Free_F1`, `Standard_S1` and `Premium_P1`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class ServiceUpstreamEndpointArgs:
    def __init__(__self__, *,
                 category_patterns: pulumi.Input[Sequence[pulumi.Input[str]]],
                 event_patterns: pulumi.Input[Sequence[pulumi.Input[str]]],
                 hub_patterns: pulumi.Input[Sequence[pulumi.Input[str]]],
                 url_template: pulumi.Input[str],
                 user_assigned_identity_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] category_patterns: The categories to match on, or `*` for all.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] event_patterns: The events to match on, or `*` for all.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] hub_patterns: The hubs to match on, or `*` for all.
        :param pulumi.Input[str] url_template: The upstream URL Template. This can be a url or a template such as `http://host.com/{hub}/api/{category}/{event}`.
        :param pulumi.Input[str] user_assigned_identity_id: Specifies the Managed Identity IDs to be assigned to this signalR upstream setting by using resource uuid as both system assigned and user assigned identity is supported.
        """
        ServiceUpstreamEndpointArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            category_patterns=category_patterns,
            event_patterns=event_patterns,
            hub_patterns=hub_patterns,
            url_template=url_template,
            user_assigned_identity_id=user_assigned_identity_id,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             category_patterns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             event_patterns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             hub_patterns: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             url_template: Optional[pulumi.Input[str]] = None,
             user_assigned_identity_id: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if category_patterns is None and 'categoryPatterns' in kwargs:
            category_patterns = kwargs['categoryPatterns']
        if category_patterns is None:
            raise TypeError("Missing 'category_patterns' argument")
        if event_patterns is None and 'eventPatterns' in kwargs:
            event_patterns = kwargs['eventPatterns']
        if event_patterns is None:
            raise TypeError("Missing 'event_patterns' argument")
        if hub_patterns is None and 'hubPatterns' in kwargs:
            hub_patterns = kwargs['hubPatterns']
        if hub_patterns is None:
            raise TypeError("Missing 'hub_patterns' argument")
        if url_template is None and 'urlTemplate' in kwargs:
            url_template = kwargs['urlTemplate']
        if url_template is None:
            raise TypeError("Missing 'url_template' argument")
        if user_assigned_identity_id is None and 'userAssignedIdentityId' in kwargs:
            user_assigned_identity_id = kwargs['userAssignedIdentityId']

        _setter("category_patterns", category_patterns)
        _setter("event_patterns", event_patterns)
        _setter("hub_patterns", hub_patterns)
        _setter("url_template", url_template)
        if user_assigned_identity_id is not None:
            _setter("user_assigned_identity_id", user_assigned_identity_id)

    @property
    @pulumi.getter(name="categoryPatterns")
    def category_patterns(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The categories to match on, or `*` for all.
        """
        return pulumi.get(self, "category_patterns")

    @category_patterns.setter
    def category_patterns(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "category_patterns", value)

    @property
    @pulumi.getter(name="eventPatterns")
    def event_patterns(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The events to match on, or `*` for all.
        """
        return pulumi.get(self, "event_patterns")

    @event_patterns.setter
    def event_patterns(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "event_patterns", value)

    @property
    @pulumi.getter(name="hubPatterns")
    def hub_patterns(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The hubs to match on, or `*` for all.
        """
        return pulumi.get(self, "hub_patterns")

    @hub_patterns.setter
    def hub_patterns(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "hub_patterns", value)

    @property
    @pulumi.getter(name="urlTemplate")
    def url_template(self) -> pulumi.Input[str]:
        """
        The upstream URL Template. This can be a url or a template such as `http://host.com/{hub}/api/{category}/{event}`.
        """
        return pulumi.get(self, "url_template")

    @url_template.setter
    def url_template(self, value: pulumi.Input[str]):
        pulumi.set(self, "url_template", value)

    @property
    @pulumi.getter(name="userAssignedIdentityId")
    def user_assigned_identity_id(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the Managed Identity IDs to be assigned to this signalR upstream setting by using resource uuid as both system assigned and user assigned identity is supported.
        """
        return pulumi.get(self, "user_assigned_identity_id")

    @user_assigned_identity_id.setter
    def user_assigned_identity_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_assigned_identity_id", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'LedgerAzureadBasedServicePrincipalArgs',
    'LedgerCertificateBasedSecurityPrincipalArgs',
]

@pulumi.input_type
class LedgerAzureadBasedServicePrincipalArgs:
    def __init__(__self__, *,
                 ledger_role_name: pulumi.Input[str],
                 principal_id: pulumi.Input[str],
                 tenant_id: pulumi.Input[str]):
        """
        :param pulumi.Input[str] ledger_role_name: Specifies the Ledger Role to grant this AzureAD Service Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        :param pulumi.Input[str] principal_id: Specifies the Principal ID of the AzureAD Service Principal.
        :param pulumi.Input[str] tenant_id: Specifies the Tenant ID for this AzureAD Service Principal.
        """
        LedgerAzureadBasedServicePrincipalArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            ledger_role_name=ledger_role_name,
            principal_id=principal_id,
            tenant_id=tenant_id,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             ledger_role_name: Optional[pulumi.Input[str]] = None,
             principal_id: Optional[pulumi.Input[str]] = None,
             tenant_id: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if ledger_role_name is None and 'ledgerRoleName' in kwargs:
            ledger_role_name = kwargs['ledgerRoleName']
        if ledger_role_name is None:
            raise TypeError("Missing 'ledger_role_name' argument")
        if principal_id is None and 'principalId' in kwargs:
            principal_id = kwargs['principalId']
        if principal_id is None:
            raise TypeError("Missing 'principal_id' argument")
        if tenant_id is None and 'tenantId' in kwargs:
            tenant_id = kwargs['tenantId']
        if tenant_id is None:
            raise TypeError("Missing 'tenant_id' argument")

        _setter("ledger_role_name", ledger_role_name)
        _setter("principal_id", principal_id)
        _setter("tenant_id", tenant_id)

    @property
    @pulumi.getter(name="ledgerRoleName")
    def ledger_role_name(self) -> pulumi.Input[str]:
        """
        Specifies the Ledger Role to grant this AzureAD Service Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        """
        return pulumi.get(self, "ledger_role_name")

    @ledger_role_name.setter
    def ledger_role_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "ledger_role_name", value)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> pulumi.Input[str]:
        """
        Specifies the Principal ID of the AzureAD Service Principal.
        """
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "principal_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Input[str]:
        """
        Specifies the Tenant ID for this AzureAD Service Principal.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "tenant_id", value)


@pulumi.input_type
class LedgerCertificateBasedSecurityPrincipalArgs:
    def __init__(__self__, *,
                 ledger_role_name: pulumi.Input[str],
                 pem_public_key: pulumi.Input[str]):
        """
        :param pulumi.Input[str] ledger_role_name: Specifies the Ledger Role to grant this Certificate Security Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        :param pulumi.Input[str] pem_public_key: The public key, in PEM format, of the certificate used by this identity to authenticate with the Confidential Ledger.
        """
        LedgerCertificateBasedSecurityPrincipalArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            ledger_role_name=ledger_role_name,
            pem_public_key=pem_public_key,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             ledger_role_name: Optional[pulumi.Input[str]] = None,
             pem_public_key: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if ledger_role_name is None and 'ledgerRoleName' in kwargs:
            ledger_role_name = kwargs['ledgerRoleName']
        if ledger_role_name is None:
            raise TypeError("Missing 'ledger_role_name' argument")
        if pem_public_key is None and 'pemPublicKey' in kwargs:
            pem_public_key = kwargs['pemPublicKey']
        if pem_public_key is None:
            raise TypeError("Missing 'pem_public_key' argument")

        _setter("ledger_role_name", ledger_role_name)
        _setter("pem_public_key", pem_public_key)

    @property
    @pulumi.getter(name="ledgerRoleName")
    def ledger_role_name(self) -> pulumi.Input[str]:
        """
        Specifies the Ledger Role to grant this Certificate Security Principal. Possible values are `Administrator`, `Contributor` and `Reader`.
        """
        return pulumi.get(self, "ledger_role_name")

    @ledger_role_name.setter
    def ledger_role_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "ledger_role_name", value)

    @property
    @pulumi.getter(name="pemPublicKey")
    def pem_public_key(self) -> pulumi.Input[str]:
        """
        The public key, in PEM format, of the certificate used by this identity to authenticate with the Confidential Ledger.
        """
        return pulumi.get(self, "pem_public_key")

    @pem_public_key.setter
    def pem_public_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "pem_public_key", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ChannelWebChatArgs', 'ChannelWebChat']

@pulumi.input_type
class ChannelWebChatArgs:
    def __init__(__self__, *,
                 bot_name: pulumi.Input[str],
                 resource_group_name: pulumi.Input[str],
                 location: Optional[pulumi.Input[str]] = None,
                 site_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 sites: Optional[pulumi.Input[Sequence[pulumi.Input['ChannelWebChatSiteArgs']]]] = None):
        """
        The set of arguments for constructing a ChannelWebChat resource.
        :param pulumi.Input[str] bot_name: The name of the Bot Resource this channel will be associated with. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group where the Web Chat Channel should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] site_names: A list of Web Chat Site names.
               
               > **NOTE:** `site_names` is deprecated and will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.
        :param pulumi.Input[Sequence[pulumi.Input['ChannelWebChatSiteArgs']]] sites: A site represents a client application that you want to connect to your bot. Multiple `site` blocks may be defined as below
        """
        ChannelWebChatArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            bot_name=bot_name,
            resource_group_name=resource_group_name,
            location=location,
            site_names=site_names,
            sites=sites,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             bot_name: Optional[pulumi.Input[str]] = None,
             resource_group_name: Optional[pulumi.Input[str]] = None,
             location: Optional[pulumi.Input[str]] = None,
             site_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             sites: Optional[pulumi.Input[Sequence[pulumi.Input['ChannelWebChatSiteArgs']]]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if bot_name is None and 'botName' in kwargs:
            bot_name = kwargs['botName']
        if bot_name is None:
            raise TypeError("Missing 'bot_name' argument")
        if resource_group_name is None and 'resourceGroupName' in kwargs:
            resource_group_name = kwargs['resourceGroupName']
        if resource_group_name is None:
            raise TypeError("Missing 'resource_group_name' argument")
        if site_names is None and 'siteNames' in kwargs:
            site_names = kwargs['siteNames']

        _setter("bot_name", bot_name)
        _setter("resource_group_name", resource_group_name)
        if location is not None:
            _setter("location", location)
        if site_names is not None:
            warnings.warn("""`site_names` will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.""", DeprecationWarning)
            pulumi.log.warn("""site_names is deprecated: `site_names` will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.""")
        if site_names is not None:
            _setter("site_names", site_names)
        if sites is not None:
            _setter("sites", sites)

    @property
    @pulumi.getter(name="botName")
    def bot_name(self) -> pulumi.Input[str]:
        """
        The name of the Bot Resource this channel will be associated with. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "bot_name")

    @bot_name.setter
    def bot_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "bot_name", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        The name of the resource group where the Web Chat Channel should be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter(name="siteNames")
    def site_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of Web Chat Site names.

        > **NOTE:** `site_names` is deprecated and will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.
        """
        warnings.warn("""`site_names` will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.""", DeprecationWarning)
        pulumi.log.warn("""site_names is deprecated: `site_names` will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.""")

        return pulumi.get(self, "site_names")

    @site_names.setter
    def site_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "site_names", value)

    @property
    @pulumi.getter
    def sites(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ChannelWebChatSiteArgs']]]]:
        """
        A site represents a client application that you want to connect to your bot. Multiple `site` blocks may be defined as below
        """
        return pulumi.get(self, "sites")

    @sites.setter
    def sites(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ChannelWebChatSiteArgs']]]]):
        pulumi.set(self, "sites", value)


@pulumi.input_type
class _ChannelWebChatState:
    def __init__(__self__, *,
                 bot_name: Optional[pulumi.Input[str]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 site_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 sites: Optional[pulumi.Input[Sequence[pulumi.Input['ChannelWebChatSiteArgs']]]] = None):
        """
        Input properties used for looking up and filtering ChannelWebChat resources.
        :param pulumi.Input[str] bot_name: The name of the Bot Resource this channel will be associated with. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group where the Web Chat Channel should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] site_names: A list of Web Chat Site names.
               
               > **NOTE:** `site_names` is deprecated and will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.
        :param pulumi.Input[Sequence[pulumi.Input['ChannelWebChatSiteArgs']]] sites: A site represents a client application that you want to connect to your bot. Multiple `site` blocks may be defined as below
        """
        _ChannelWebChatState._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            bot_name=bot_name,
            location=location,
            resource_group_name=resource_group_name,
            site_names=site_names,
            sites=sites,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             bot_name: Optional[pulumi.Input[str]] = None,
             location: Optional[pulumi.Input[str]] = None,
             resource_group_name: Optional[pulumi.Input[str]] = None,
             site_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             sites: Optional[pulumi.Input[Sequence[pulumi.Input['ChannelWebChatSiteArgs']]]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if bot_name is None and 'botName' in kwargs:
            bot_name = kwargs['botName']
        if resource_group_name is None and 'resourceGroupName' in kwargs:
            resource_group_name = kwargs['resourceGroupName']
        if site_names is None and 'siteNames' in kwargs:
            site_names = kwargs['siteNames']

        if bot_name is not None:
            _setter("bot_name", bot_name)
        if location is not None:
            _setter("location", location)
        if resource_group_name is not None:
            _setter("resource_group_name", resource_group_name)
        if site_names is not None:
            warnings.warn("""`site_names` will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.""", DeprecationWarning)
            pulumi.log.warn("""site_names is deprecated: `site_names` will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.""")
        if site_names is not None:
            _setter("site_names", site_names)
        if sites is not None:
            _setter("sites", sites)

    @property
    @pulumi.getter(name="botName")
    def bot_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Bot Resource this channel will be associated with. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "bot_name")

    @bot_name.setter
    def bot_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bot_name", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource group where the Web Chat Channel should be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="siteNames")
    def site_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of Web Chat Site names.

        > **NOTE:** `site_names` is deprecated and will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.
        """
        warnings.warn("""`site_names` will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.""", DeprecationWarning)
        pulumi.log.warn("""site_names is deprecated: `site_names` will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.""")

        return pulumi.get(self, "site_names")

    @site_names.setter
    def site_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "site_names", value)

    @property
    @pulumi.getter
    def sites(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ChannelWebChatSiteArgs']]]]:
        """
        A site represents a client application that you want to connect to your bot. Multiple `site` blocks may be defined as below
        """
        return pulumi.get(self, "sites")

    @sites.setter
    def sites(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ChannelWebChatSiteArgs']]]]):
        pulumi.set(self, "sites", value)


class ChannelWebChat(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bot_name: Optional[pulumi.Input[str]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 site_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 sites: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ChannelWebChatSiteArgs']]]]] = None,
                 __props__=None):
        """
        Manages a Web Chat integration for a Bot Channel

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        current = azure.core.get_client_config()
        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_channels_registration = azure.bot.ChannelsRegistration("exampleChannelsRegistration",
            location="global",
            resource_group_name=example_resource_group.name,
            sku="F0",
            microsoft_app_id=current.client_id)
        example_channel_web_chat = azure.bot.ChannelWebChat("exampleChannelWebChat",
            bot_name=example_channels_registration.name,
            location=example_channels_registration.location,
            resource_group_name=example_resource_group.name,
            sites=[azure.bot.ChannelWebChatSiteArgs(
                name="TestSite",
            )])
        ```

        ## Import

        Web Chat Channels can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:bot/channelWebChat:ChannelWebChat example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.BotService/botServices/botService1/channels/WebChatChannel
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bot_name: The name of the Bot Resource this channel will be associated with. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group where the Web Chat Channel should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] site_names: A list of Web Chat Site names.
               
               > **NOTE:** `site_names` is deprecated and will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ChannelWebChatSiteArgs']]]] sites: A site represents a client application that you want to connect to your bot. Multiple `site` blocks may be defined as below
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ChannelWebChatArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Web Chat integration for a Bot Channel

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        current = azure.core.get_client_config()
        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_channels_registration = azure.bot.ChannelsRegistration("exampleChannelsRegistration",
            location="global",
            resource_group_name=example_resource_group.name,
            sku="F0",
            microsoft_app_id=current.client_id)
        example_channel_web_chat = azure.bot.ChannelWebChat("exampleChannelWebChat",
            bot_name=example_channels_registration.name,
            location=example_channels_registration.location,
            resource_group_name=example_resource_group.name,
            sites=[azure.bot.ChannelWebChatSiteArgs(
                name="TestSite",
            )])
        ```

        ## Import

        Web Chat Channels can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:bot/channelWebChat:ChannelWebChat example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.BotService/botServices/botService1/channels/WebChatChannel
        ```

        :param str resource_name: The name of the resource.
        :param ChannelWebChatArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ChannelWebChatArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            kwargs = kwargs or {}
            def _setter(key, value):
                kwargs[key] = value
            ChannelWebChatArgs._configure(_setter, **kwargs)
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bot_name: Optional[pulumi.Input[str]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 site_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 sites: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ChannelWebChatSiteArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ChannelWebChatArgs.__new__(ChannelWebChatArgs)

            if bot_name is None and not opts.urn:
                raise TypeError("Missing required property 'bot_name'")
            __props__.__dict__["bot_name"] = bot_name
            __props__.__dict__["location"] = location
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["site_names"] = site_names
            __props__.__dict__["sites"] = sites
        super(ChannelWebChat, __self__).__init__(
            'azure:bot/channelWebChat:ChannelWebChat',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bot_name: Optional[pulumi.Input[str]] = None,
            location: Optional[pulumi.Input[str]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            site_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            sites: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ChannelWebChatSiteArgs']]]]] = None) -> 'ChannelWebChat':
        """
        Get an existing ChannelWebChat resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bot_name: The name of the Bot Resource this channel will be associated with. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group where the Web Chat Channel should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] site_names: A list of Web Chat Site names.
               
               > **NOTE:** `site_names` is deprecated and will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ChannelWebChatSiteArgs']]]] sites: A site represents a client application that you want to connect to your bot. Multiple `site` blocks may be defined as below
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ChannelWebChatState.__new__(_ChannelWebChatState)

        __props__.__dict__["bot_name"] = bot_name
        __props__.__dict__["location"] = location
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["site_names"] = site_names
        __props__.__dict__["sites"] = sites
        return ChannelWebChat(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="botName")
    def bot_name(self) -> pulumi.Output[str]:
        """
        The name of the Bot Resource this channel will be associated with. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "bot_name")

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[str]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        The name of the resource group where the Web Chat Channel should be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter(name="siteNames")
    def site_names(self) -> pulumi.Output[Sequence[str]]:
        """
        A list of Web Chat Site names.

        > **NOTE:** `site_names` is deprecated and will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.
        """
        warnings.warn("""`site_names` will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.""", DeprecationWarning)
        pulumi.log.warn("""site_names is deprecated: `site_names` will be removed in favour of the property `site` in version 4.0 of the AzureRM Provider.""")

        return pulumi.get(self, "site_names")

    @property
    @pulumi.getter
    def sites(self) -> pulumi.Output[Sequence['outputs.ChannelWebChatSite']]:
        """
        A site represents a client application that you want to connect to your bot. Multiple `site` blocks may be defined as below
        """
        return pulumi.get(self, "sites")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'ConfigurationFeatureTargetingFilter',
    'ConfigurationFeatureTargetingFilterGroup',
    'ConfigurationFeatureTimewindowFilter',
    'ConfigurationStoreEncryption',
    'ConfigurationStoreIdentity',
    'ConfigurationStorePrimaryReadKey',
    'ConfigurationStorePrimaryWriteKey',
    'ConfigurationStoreReplica',
    'ConfigurationStoreSecondaryReadKey',
    'ConfigurationStoreSecondaryWriteKey',
    'GetConfigurationKeysItemResult',
    'GetConfigurationStoreEncryptionResult',
    'GetConfigurationStoreIdentityResult',
    'GetConfigurationStorePrimaryReadKeyResult',
    'GetConfigurationStorePrimaryWriteKeyResult',
    'GetConfigurationStoreReplicaResult',
    'GetConfigurationStoreSecondaryReadKeyResult',
    'GetConfigurationStoreSecondaryWriteKeyResult',
]

@pulumi.output_type
class ConfigurationFeatureTargetingFilter(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "defaultRolloutPercentage":
            suggest = "default_rollout_percentage"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConfigurationFeatureTargetingFilter. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConfigurationFeatureTargetingFilter.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConfigurationFeatureTargetingFilter.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 default_rollout_percentage: int,
                 groups: Optional[Sequence['outputs.ConfigurationFeatureTargetingFilterGroup']] = None,
                 users: Optional[Sequence[str]] = None):
        """
        :param int default_rollout_percentage: A number representing the percentage of the entire user base.
        :param Sequence['ConfigurationFeatureTargetingFilterGroupArgs'] groups: One or more blocks of type `groups` as defined below.
        :param Sequence[str] users: A list of users to target for this feature.
        """
        ConfigurationFeatureTargetingFilter._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            default_rollout_percentage=default_rollout_percentage,
            groups=groups,
            users=users,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             default_rollout_percentage: Optional[int] = None,
             groups: Optional[Sequence['outputs.ConfigurationFeatureTargetingFilterGroup']] = None,
             users: Optional[Sequence[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if default_rollout_percentage is None and 'defaultRolloutPercentage' in kwargs:
            default_rollout_percentage = kwargs['defaultRolloutPercentage']
        if default_rollout_percentage is None:
            raise TypeError("Missing 'default_rollout_percentage' argument")

        _setter("default_rollout_percentage", default_rollout_percentage)
        if groups is not None:
            _setter("groups", groups)
        if users is not None:
            _setter("users", users)

    @property
    @pulumi.getter(name="defaultRolloutPercentage")
    def default_rollout_percentage(self) -> int:
        """
        A number representing the percentage of the entire user base.
        """
        return pulumi.get(self, "default_rollout_percentage")

    @property
    @pulumi.getter
    def groups(self) -> Optional[Sequence['outputs.ConfigurationFeatureTargetingFilterGroup']]:
        """
        One or more blocks of type `groups` as defined below.
        """
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def users(self) -> Optional[Sequence[str]]:
        """
        A list of users to target for this feature.
        """
        return pulumi.get(self, "users")


@pulumi.output_type
class ConfigurationFeatureTargetingFilterGroup(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "rolloutPercentage":
            suggest = "rollout_percentage"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConfigurationFeatureTargetingFilterGroup. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConfigurationFeatureTargetingFilterGroup.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConfigurationFeatureTargetingFilterGroup.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: str,
                 rollout_percentage: int):
        """
        :param str name: The name of the group.
        :param int rollout_percentage: Rollout percentage of the group.
        """
        ConfigurationFeatureTargetingFilterGroup._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            name=name,
            rollout_percentage=rollout_percentage,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             name: Optional[str] = None,
             rollout_percentage: Optional[int] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if name is None:
            raise TypeError("Missing 'name' argument")
        if rollout_percentage is None and 'rolloutPercentage' in kwargs:
            rollout_percentage = kwargs['rolloutPercentage']
        if rollout_percentage is None:
            raise TypeError("Missing 'rollout_percentage' argument")

        _setter("name", name)
        _setter("rollout_percentage", rollout_percentage)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the group.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="rolloutPercentage")
    def rollout_percentage(self) -> int:
        """
        Rollout percentage of the group.
        """
        return pulumi.get(self, "rollout_percentage")


@pulumi.output_type
class ConfigurationFeatureTimewindowFilter(dict):
    def __init__(__self__, *,
                 end: Optional[str] = None,
                 start: Optional[str] = None):
        """
        :param str end: The latest timestamp the feature is enabled. The timestamp must be in RFC3339 format.
        :param str start: The earliest timestamp the feature is enabled. The timestamp must be in RFC3339 format.
        """
        ConfigurationFeatureTimewindowFilter._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            end=end,
            start=start,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             end: Optional[str] = None,
             start: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):

        if end is not None:
            _setter("end", end)
        if start is not None:
            _setter("start", start)

    @property
    @pulumi.getter
    def end(self) -> Optional[str]:
        """
        The latest timestamp the feature is enabled. The timestamp must be in RFC3339 format.
        """
        return pulumi.get(self, "end")

    @property
    @pulumi.getter
    def start(self) -> Optional[str]:
        """
        The earliest timestamp the feature is enabled. The timestamp must be in RFC3339 format.
        """
        return pulumi.get(self, "start")


@pulumi.output_type
class ConfigurationStoreEncryption(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityClientId":
            suggest = "identity_client_id"
        elif key == "keyVaultKeyIdentifier":
            suggest = "key_vault_key_identifier"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConfigurationStoreEncryption. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConfigurationStoreEncryption.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConfigurationStoreEncryption.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 identity_client_id: Optional[str] = None,
                 key_vault_key_identifier: Optional[str] = None):
        """
        :param str identity_client_id: Specifies the client id of the identity which will be used to access key vault.
        :param str key_vault_key_identifier: Specifies the URI of the key vault key used to encrypt data.
        """
        ConfigurationStoreEncryption._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            identity_client_id=identity_client_id,
            key_vault_key_identifier=key_vault_key_identifier,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             identity_client_id: Optional[str] = None,
             key_vault_key_identifier: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if identity_client_id is None and 'identityClientId' in kwargs:
            identity_client_id = kwargs['identityClientId']
        if key_vault_key_identifier is None and 'keyVaultKeyIdentifier' in kwargs:
            key_vault_key_identifier = kwargs['keyVaultKeyIdentifier']

        if identity_client_id is not None:
            _setter("identity_client_id", identity_client_id)
        if key_vault_key_identifier is not None:
            _setter("key_vault_key_identifier", key_vault_key_identifier)

    @property
    @pulumi.getter(name="identityClientId")
    def identity_client_id(self) -> Optional[str]:
        """
        Specifies the client id of the identity which will be used to access key vault.
        """
        return pulumi.get(self, "identity_client_id")

    @property
    @pulumi.getter(name="keyVaultKeyIdentifier")
    def key_vault_key_identifier(self) -> Optional[str]:
        """
        Specifies the URI of the key vault key used to encrypt data.
        """
        return pulumi.get(self, "key_vault_key_identifier")


@pulumi.output_type
class ConfigurationStoreIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityIds":
            suggest = "identity_ids"
        elif key == "principalId":
            suggest = "principal_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConfigurationStoreIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConfigurationStoreIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConfigurationStoreIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 identity_ids: Optional[Sequence[str]] = None,
                 principal_id: Optional[str] = None,
                 tenant_id: Optional[str] = None):
        """
        :param str type: Specifies the type of Managed Service Identity that should be configured on this App Configuration. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        :param Sequence[str] identity_ids: A list of User Assigned Managed Identity IDs to be assigned to this App Configuration.
               
               > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        :param str principal_id: The Principal ID associated with this Managed Service Identity.
        :param str tenant_id: The Tenant ID associated with this Managed Service Identity.
        """
        ConfigurationStoreIdentity._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            type=type,
            identity_ids=identity_ids,
            principal_id=principal_id,
            tenant_id=tenant_id,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             type: Optional[str] = None,
             identity_ids: Optional[Sequence[str]] = None,
             principal_id: Optional[str] = None,
             tenant_id: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if type is None:
            raise TypeError("Missing 'type' argument")
        if identity_ids is None and 'identityIds' in kwargs:
            identity_ids = kwargs['identityIds']
        if principal_id is None and 'principalId' in kwargs:
            principal_id = kwargs['principalId']
        if tenant_id is None and 'tenantId' in kwargs:
            tenant_id = kwargs['tenantId']

        _setter("type", type)
        if identity_ids is not None:
            _setter("identity_ids", identity_ids)
        if principal_id is not None:
            _setter("principal_id", principal_id)
        if tenant_id is not None:
            _setter("tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Specifies the type of Managed Service Identity that should be configured on this App Configuration. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[Sequence[str]]:
        """
        A list of User Assigned Managed Identity IDs to be assigned to this App Configuration.

        > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[str]:
        """
        The Principal ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[str]:
        """
        The Tenant ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class ConfigurationStorePrimaryReadKey(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectionString":
            suggest = "connection_string"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConfigurationStorePrimaryReadKey. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConfigurationStorePrimaryReadKey.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConfigurationStorePrimaryReadKey.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 connection_string: Optional[str] = None,
                 id: Optional[str] = None,
                 secret: Optional[str] = None):
        """
        :param str connection_string: The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        :param str id: The ID of the Access Key.
        :param str secret: The Secret of the Access Key.
        """
        ConfigurationStorePrimaryReadKey._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            connection_string=connection_string,
            id=id,
            secret=secret,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             connection_string: Optional[str] = None,
             id: Optional[str] = None,
             secret: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if connection_string is None and 'connectionString' in kwargs:
            connection_string = kwargs['connectionString']

        if connection_string is not None:
            _setter("connection_string", connection_string)
        if id is not None:
            _setter("id", id)
        if secret is not None:
            _setter("secret", secret)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[str]:
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def secret(self) -> Optional[str]:
        """
        The Secret of the Access Key.
        """
        return pulumi.get(self, "secret")


@pulumi.output_type
class ConfigurationStorePrimaryWriteKey(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectionString":
            suggest = "connection_string"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConfigurationStorePrimaryWriteKey. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConfigurationStorePrimaryWriteKey.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConfigurationStorePrimaryWriteKey.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 connection_string: Optional[str] = None,
                 id: Optional[str] = None,
                 secret: Optional[str] = None):
        """
        :param str connection_string: The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        :param str id: The ID of the Access Key.
        :param str secret: The Secret of the Access Key.
        """
        ConfigurationStorePrimaryWriteKey._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            connection_string=connection_string,
            id=id,
            secret=secret,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             connection_string: Optional[str] = None,
             id: Optional[str] = None,
             secret: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if connection_string is None and 'connectionString' in kwargs:
            connection_string = kwargs['connectionString']

        if connection_string is not None:
            _setter("connection_string", connection_string)
        if id is not None:
            _setter("id", id)
        if secret is not None:
            _setter("secret", secret)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[str]:
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def secret(self) -> Optional[str]:
        """
        The Secret of the Access Key.
        """
        return pulumi.get(self, "secret")


@pulumi.output_type
class ConfigurationStoreReplica(dict):
    def __init__(__self__, *,
                 location: str,
                 name: str,
                 endpoint: Optional[str] = None,
                 id: Optional[str] = None):
        """
        :param str location: Specifies the supported Azure location where the replica exists. Changing this forces a new replica to be created.
        :param str name: Specifies the name of the replica. Changing this forces a new replica to be created.
        :param str endpoint: The URL of the App Configuration Replica.
        :param str id: The ID of the Access Key.
        """
        ConfigurationStoreReplica._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            location=location,
            name=name,
            endpoint=endpoint,
            id=id,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             location: Optional[str] = None,
             name: Optional[str] = None,
             endpoint: Optional[str] = None,
             id: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if location is None:
            raise TypeError("Missing 'location' argument")
        if name is None:
            raise TypeError("Missing 'name' argument")

        _setter("location", location)
        _setter("name", name)
        if endpoint is not None:
            _setter("endpoint", endpoint)
        if id is not None:
            _setter("id", id)

    @property
    @pulumi.getter
    def location(self) -> str:
        """
        Specifies the supported Azure location where the replica exists. Changing this forces a new replica to be created.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Specifies the name of the replica. Changing this forces a new replica to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def endpoint(self) -> Optional[str]:
        """
        The URL of the App Configuration Replica.
        """
        return pulumi.get(self, "endpoint")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")


@pulumi.output_type
class ConfigurationStoreSecondaryReadKey(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectionString":
            suggest = "connection_string"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConfigurationStoreSecondaryReadKey. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConfigurationStoreSecondaryReadKey.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConfigurationStoreSecondaryReadKey.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 connection_string: Optional[str] = None,
                 id: Optional[str] = None,
                 secret: Optional[str] = None):
        """
        :param str connection_string: The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        :param str id: The ID of the Access Key.
        :param str secret: The Secret of the Access Key.
        """
        ConfigurationStoreSecondaryReadKey._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            connection_string=connection_string,
            id=id,
            secret=secret,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             connection_string: Optional[str] = None,
             id: Optional[str] = None,
             secret: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if connection_string is None and 'connectionString' in kwargs:
            connection_string = kwargs['connectionString']

        if connection_string is not None:
            _setter("connection_string", connection_string)
        if id is not None:
            _setter("id", id)
        if secret is not None:
            _setter("secret", secret)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[str]:
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def secret(self) -> Optional[str]:
        """
        The Secret of the Access Key.
        """
        return pulumi.get(self, "secret")


@pulumi.output_type
class ConfigurationStoreSecondaryWriteKey(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "connectionString":
            suggest = "connection_string"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConfigurationStoreSecondaryWriteKey. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConfigurationStoreSecondaryWriteKey.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConfigurationStoreSecondaryWriteKey.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 connection_string: Optional[str] = None,
                 id: Optional[str] = None,
                 secret: Optional[str] = None):
        """
        :param str connection_string: The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        :param str id: The ID of the Access Key.
        :param str secret: The Secret of the Access Key.
        """
        ConfigurationStoreSecondaryWriteKey._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            connection_string=connection_string,
            id=id,
            secret=secret,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             connection_string: Optional[str] = None,
             id: Optional[str] = None,
             secret: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if connection_string is None and 'connectionString' in kwargs:
            connection_string = kwargs['connectionString']

        if connection_string is not None:
            _setter("connection_string", connection_string)
        if id is not None:
            _setter("id", id)
        if secret is not None:
            _setter("secret", secret)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[str]:
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def secret(self) -> Optional[str]:
        """
        The Secret of the Access Key.
        """
        return pulumi.get(self, "secret")


@pulumi.output_type
class GetConfigurationKeysItemResult(dict):
    def __init__(__self__, *,
                 content_type: str,
                 etag: str,
                 key: str,
                 label: str,
                 locked: bool,
                 tags: Mapping[str, str],
                 type: str,
                 value: str,
                 vault_key_reference: str):
        """
        :param str content_type: The content type of the App Configuration Key.
        :param str etag: The ETag of the key.
        :param str key: The name of the App Configuration Keys to look up.
        :param str label: The label of the App Configuration Keys tp look up.
        :param bool locked: Is this App Configuration Key be Locked to prevent changes.
        :param Mapping[str, str] tags: A mapping of tags assigned to the resource.
        :param str type: The type of the App Configuration Key. It can either be `kv` (simple [key/value](https://docs.microsoft.com/azure/azure-app-configuration/concept-key-value)) or `vault` (where the value is a reference to a [Key Vault Secret](https://azure.microsoft.com/en-gb/services/key-vault/).
        :param str value: The value of the App Configuration Key.
        :param str vault_key_reference: The ID of the vault secret this App Configuration Key refers to, when `type` is `vault`.
        """
        GetConfigurationKeysItemResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            content_type=content_type,
            etag=etag,
            key=key,
            label=label,
            locked=locked,
            tags=tags,
            type=type,
            value=value,
            vault_key_reference=vault_key_reference,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             content_type: Optional[str] = None,
             etag: Optional[str] = None,
             key: Optional[str] = None,
             label: Optional[str] = None,
             locked: Optional[bool] = None,
             tags: Optional[Mapping[str, str]] = None,
             type: Optional[str] = None,
             value: Optional[str] = None,
             vault_key_reference: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if content_type is None and 'contentType' in kwargs:
            content_type = kwargs['contentType']
        if content_type is None:
            raise TypeError("Missing 'content_type' argument")
        if etag is None:
            raise TypeError("Missing 'etag' argument")
        if key is None:
            raise TypeError("Missing 'key' argument")
        if label is None:
            raise TypeError("Missing 'label' argument")
        if locked is None:
            raise TypeError("Missing 'locked' argument")
        if tags is None:
            raise TypeError("Missing 'tags' argument")
        if type is None:
            raise TypeError("Missing 'type' argument")
        if value is None:
            raise TypeError("Missing 'value' argument")
        if vault_key_reference is None and 'vaultKeyReference' in kwargs:
            vault_key_reference = kwargs['vaultKeyReference']
        if vault_key_reference is None:
            raise TypeError("Missing 'vault_key_reference' argument")

        _setter("content_type", content_type)
        _setter("etag", etag)
        _setter("key", key)
        _setter("label", label)
        _setter("locked", locked)
        _setter("tags", tags)
        _setter("type", type)
        _setter("value", value)
        _setter("vault_key_reference", vault_key_reference)

    @property
    @pulumi.getter(name="contentType")
    def content_type(self) -> str:
        """
        The content type of the App Configuration Key.
        """
        return pulumi.get(self, "content_type")

    @property
    @pulumi.getter
    def etag(self) -> str:
        """
        The ETag of the key.
        """
        return pulumi.get(self, "etag")

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The name of the App Configuration Keys to look up.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def label(self) -> str:
        """
        The label of the App Configuration Keys tp look up.
        """
        return pulumi.get(self, "label")

    @property
    @pulumi.getter
    def locked(self) -> bool:
        """
        Is this App Configuration Key be Locked to prevent changes.
        """
        return pulumi.get(self, "locked")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        """
        A mapping of tags assigned to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The type of the App Configuration Key. It can either be `kv` (simple [key/value](https://docs.microsoft.com/azure/azure-app-configuration/concept-key-value)) or `vault` (where the value is a reference to a [Key Vault Secret](https://azure.microsoft.com/en-gb/services/key-vault/).
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value of the App Configuration Key.
        """
        return pulumi.get(self, "value")

    @property
    @pulumi.getter(name="vaultKeyReference")
    def vault_key_reference(self) -> str:
        """
        The ID of the vault secret this App Configuration Key refers to, when `type` is `vault`.
        """
        return pulumi.get(self, "vault_key_reference")


@pulumi.output_type
class GetConfigurationStoreEncryptionResult(dict):
    def __init__(__self__, *,
                 identity_client_id: str,
                 key_vault_key_identifier: str):
        GetConfigurationStoreEncryptionResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            identity_client_id=identity_client_id,
            key_vault_key_identifier=key_vault_key_identifier,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             identity_client_id: Optional[str] = None,
             key_vault_key_identifier: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if identity_client_id is None and 'identityClientId' in kwargs:
            identity_client_id = kwargs['identityClientId']
        if identity_client_id is None:
            raise TypeError("Missing 'identity_client_id' argument")
        if key_vault_key_identifier is None and 'keyVaultKeyIdentifier' in kwargs:
            key_vault_key_identifier = kwargs['keyVaultKeyIdentifier']
        if key_vault_key_identifier is None:
            raise TypeError("Missing 'key_vault_key_identifier' argument")

        _setter("identity_client_id", identity_client_id)
        _setter("key_vault_key_identifier", key_vault_key_identifier)

    @property
    @pulumi.getter(name="identityClientId")
    def identity_client_id(self) -> str:
        return pulumi.get(self, "identity_client_id")

    @property
    @pulumi.getter(name="keyVaultKeyIdentifier")
    def key_vault_key_identifier(self) -> str:
        return pulumi.get(self, "key_vault_key_identifier")


@pulumi.output_type
class GetConfigurationStoreIdentityResult(dict):
    def __init__(__self__, *,
                 identity_ids: Sequence[str],
                 principal_id: str,
                 tenant_id: str,
                 type: str):
        GetConfigurationStoreIdentityResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            identity_ids=identity_ids,
            principal_id=principal_id,
            tenant_id=tenant_id,
            type=type,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             identity_ids: Optional[Sequence[str]] = None,
             principal_id: Optional[str] = None,
             tenant_id: Optional[str] = None,
             type: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if identity_ids is None and 'identityIds' in kwargs:
            identity_ids = kwargs['identityIds']
        if identity_ids is None:
            raise TypeError("Missing 'identity_ids' argument")
        if principal_id is None and 'principalId' in kwargs:
            principal_id = kwargs['principalId']
        if principal_id is None:
            raise TypeError("Missing 'principal_id' argument")
        if tenant_id is None and 'tenantId' in kwargs:
            tenant_id = kwargs['tenantId']
        if tenant_id is None:
            raise TypeError("Missing 'tenant_id' argument")
        if type is None:
            raise TypeError("Missing 'type' argument")

        _setter("identity_ids", identity_ids)
        _setter("principal_id", principal_id)
        _setter("tenant_id", tenant_id)
        _setter("type", type)

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Sequence[str]:
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> str:
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")


@pulumi.output_type
class GetConfigurationStorePrimaryReadKeyResult(dict):
    def __init__(__self__, *,
                 connection_string: str,
                 id: str,
                 secret: str):
        """
        :param str connection_string: The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        :param str id: The ID of the Access Key.
        :param str secret: The Secret of the Access Key.
        """
        GetConfigurationStorePrimaryReadKeyResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            connection_string=connection_string,
            id=id,
            secret=secret,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             connection_string: Optional[str] = None,
             id: Optional[str] = None,
             secret: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if connection_string is None and 'connectionString' in kwargs:
            connection_string = kwargs['connectionString']
        if connection_string is None:
            raise TypeError("Missing 'connection_string' argument")
        if id is None:
            raise TypeError("Missing 'id' argument")
        if secret is None:
            raise TypeError("Missing 'secret' argument")

        _setter("connection_string", connection_string)
        _setter("id", id)
        _setter("secret", secret)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> str:
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def secret(self) -> str:
        """
        The Secret of the Access Key.
        """
        return pulumi.get(self, "secret")


@pulumi.output_type
class GetConfigurationStorePrimaryWriteKeyResult(dict):
    def __init__(__self__, *,
                 connection_string: str,
                 id: str,
                 secret: str):
        """
        :param str connection_string: The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        :param str id: The ID of the Access Key.
        :param str secret: The Secret of the Access Key.
        """
        GetConfigurationStorePrimaryWriteKeyResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            connection_string=connection_string,
            id=id,
            secret=secret,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             connection_string: Optional[str] = None,
             id: Optional[str] = None,
             secret: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if connection_string is None and 'connectionString' in kwargs:
            connection_string = kwargs['connectionString']
        if connection_string is None:
            raise TypeError("Missing 'connection_string' argument")
        if id is None:
            raise TypeError("Missing 'id' argument")
        if secret is None:
            raise TypeError("Missing 'secret' argument")

        _setter("connection_string", connection_string)
        _setter("id", id)
        _setter("secret", secret)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> str:
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def secret(self) -> str:
        """
        The Secret of the Access Key.
        """
        return pulumi.get(self, "secret")


@pulumi.output_type
class GetConfigurationStoreReplicaResult(dict):
    def __init__(__self__, *,
                 endpoint: str,
                 id: str,
                 location: str,
                 name: str):
        """
        :param str endpoint: The URL of the App Configuration Replica.
        :param str id: The ID of the Access Key.
        :param str location: The supported Azure location where the App Configuration Replica exists.
        :param str name: The Name of this App Configuration.
        """
        GetConfigurationStoreReplicaResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            endpoint=endpoint,
            id=id,
            location=location,
            name=name,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             endpoint: Optional[str] = None,
             id: Optional[str] = None,
             location: Optional[str] = None,
             name: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if endpoint is None:
            raise TypeError("Missing 'endpoint' argument")
        if id is None:
            raise TypeError("Missing 'id' argument")
        if location is None:
            raise TypeError("Missing 'location' argument")
        if name is None:
            raise TypeError("Missing 'name' argument")

        _setter("endpoint", endpoint)
        _setter("id", id)
        _setter("location", location)
        _setter("name", name)

    @property
    @pulumi.getter
    def endpoint(self) -> str:
        """
        The URL of the App Configuration Replica.
        """
        return pulumi.get(self, "endpoint")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def location(self) -> str:
        """
        The supported Azure location where the App Configuration Replica exists.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The Name of this App Configuration.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetConfigurationStoreSecondaryReadKeyResult(dict):
    def __init__(__self__, *,
                 connection_string: str,
                 id: str,
                 secret: str):
        """
        :param str connection_string: The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        :param str id: The ID of the Access Key.
        :param str secret: The Secret of the Access Key.
        """
        GetConfigurationStoreSecondaryReadKeyResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            connection_string=connection_string,
            id=id,
            secret=secret,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             connection_string: Optional[str] = None,
             id: Optional[str] = None,
             secret: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if connection_string is None and 'connectionString' in kwargs:
            connection_string = kwargs['connectionString']
        if connection_string is None:
            raise TypeError("Missing 'connection_string' argument")
        if id is None:
            raise TypeError("Missing 'id' argument")
        if secret is None:
            raise TypeError("Missing 'secret' argument")

        _setter("connection_string", connection_string)
        _setter("id", id)
        _setter("secret", secret)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> str:
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def secret(self) -> str:
        """
        The Secret of the Access Key.
        """
        return pulumi.get(self, "secret")


@pulumi.output_type
class GetConfigurationStoreSecondaryWriteKeyResult(dict):
    def __init__(__self__, *,
                 connection_string: str,
                 id: str,
                 secret: str):
        """
        :param str connection_string: The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        :param str id: The ID of the Access Key.
        :param str secret: The Secret of the Access Key.
        """
        GetConfigurationStoreSecondaryWriteKeyResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            connection_string=connection_string,
            id=id,
            secret=secret,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             connection_string: Optional[str] = None,
             id: Optional[str] = None,
             secret: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if connection_string is None and 'connectionString' in kwargs:
            connection_string = kwargs['connectionString']
        if connection_string is None:
            raise TypeError("Missing 'connection_string' argument")
        if id is None:
            raise TypeError("Missing 'id' argument")
        if secret is None:
            raise TypeError("Missing 'secret' argument")

        _setter("connection_string", connection_string)
        _setter("id", id)
        _setter("secret", secret)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> str:
        """
        The Connection String for this Access Key - comprising of the Endpoint, ID and Secret.
        """
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Access Key.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def secret(self) -> str:
        """
        The Secret of the Access Key.
        """
        return pulumi.get(self, "secret")


